from setuptools import setup

setup(name='pws',
    version='0.1.1',
    description='The most secure password keeper ever',
    url='https://bitbucket.org/mattc41190/pws',
    author='Matthew Cale',
    author_email='mattc41190@gmail.com',
    license='MIT',
    packages=['pws'],
    zip_safe=False
)
